Keywords: Supreme Court of the United States, Supreme Court, Supreme Court of US, Supremecourt, United State Supreme Court, US Supreme Court, U.S. Supreme Court, Court, Opinions, In-Chambers Opinions, 2005 Term

Visiting the Court | Touring the Building | Exhibitions

Search: All Documents Docket Advanced Search
Enter Search Text: Search term too short Invalid text in search term. Try again

Home | Opinions | 2015 Term In-Chambers Opinions

### 2015 Term In-Chambers Opinions

An in-chambers opinion is written by an individual Justice, usually the Justice for the Circuit from which the case arises, to dispose of an application by a party to the case for interim relief, e.g., for a stay of the judgment of the court below, for vacation of a stay, or for a temporary injunction. Any in-chambers opinions written during October Term 2015 (October 5, 2015, through October 2, 2016), will be posted here on the day of their issuance. They will remain posted until the opinions for the entire Term are published in the bound volumes of the United States Reports. For further information, see Column Header Definitions.

Caution: These electronic opinions may contain computer-generated errors or other deviations from the official paper versions of the opinions. Moreover, the original version of an in-chambers opinion is replaced by a paginated version of the opinion in the preliminary print, and, subsequently, by the final version of the case in a U. S. Reports bound volume. In case of discrepancies between the print and electronic versions of an in-chambers opinion, the print version controls. However, where the electronic version has been designated “revised,” the electronic version controls to the extent that it differs from the print version with regard to the noted revision. In case of discrepancies between the initial print version or electronic version of an in-chambers opinion and any later official version of the opinion—i.e., the preliminary print or bound volume version—the later version controls.

Date | Docket | Name | Revised | J. | Pt.
--- | --- | --- | --- | --- | ---

February 12, 2016 | Version 2014.1
Home | Help | Site Map | Contact Us | About Us | FAQ | Jobs | Links | Building Regulations
Website Policies and Notices | Privacy Policy | USA.GOV
Supreme Court of the United States